Struct DecoderBuffered

pub struct DecoderBuffered<C = Config> { /* private fields */ }
A (de)serializer for the classic FIX tag-value encoding.

The FIX tag-value encoding is designed to be both human-readable and easy for machines to parse.

Please reach out to the FIX official documentation12 for more information.

Implementations

Source

impl<C> DecoderBuffered<C>
where C: Configure,

pub fn supply_buffer(&mut self) -> &mut [u8]

Provides a buffer that must be filled before re-attempting to deserialize the next Message.

DecoderBuffered::supply_buffer is guaranteed to be non-empty.

Panics

Panics if the last call to DecoderBuffered::parse returned an Err.

pub fn clear(&mut self)

Completes erases the contents of the internal buffer of self.

pub fn parse(&mut self) -> Result<Option<()>, DecodeError>

After filling the buffer provided by DecoderBuffered::supply_buffer, attempt to read its contents. It returns:

pub fn message(&self) -> Message<'_, &[u8]>

Panics

Panics if DecoderBuffered::parse() didn’t return [Ok(Some(()))].